@@ -1,47 +1,15 @@
 #  File ergm/R/edgelist.ergm.R
-#  Part of the statnet package, http://statnetproject.org
+#  Part of the statnet package, http://statnet.org
 #
 #  This software is distributed under the GPL-3 license.  It is free,
 #  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnetproject.org/attribution
+#    http://statnet.org/attribution
 #
-#  Copyright 2011 the statnet development team
+#  Copyright 2012 the statnet development team
 ######################################################################
-#=========================================================================
-# This file contains the following 4 functions for converting various
-# objects into edgelists:
-#        <edgelist.ergm>
-#        <edgelist.ergm.default>
-#        <edgelist.ergm.network>
-#        <edgelist.ergm.matrix>
-#=========================================================================
-
-
-
-
-
-
 ##########################################################################
 # Each of the <edgelist.ergm.x> functions converts an object x into an
 # edgelist.
-#
-# --PARAMETERS--
-#   x   :  either a network, a matrix, or null
-#   ... :  additional paramters which may include:
-#      directed        : whether the edgelist shall be directed (T or F);
-#                        default=TRUE;
-#      check.uniqueness: whether edges must be unique (T or F);
-#                        default=TRUE;
-#      check.sorted    : whether to sort the edgelist (T or F);
-#                        default=TRUE;
-#
-# --RETURNED--
-#   the edge list corresponding to x under the following assumptions about
-#   x as a matrix:
-#    (i) if x is originally 2 columns, it was already an edgelist
-#    (2) if x is originally square, it is a non-bipartite adjacency matrix
-#    (3) if x is originally rectangular, it is a bipartite adjacency matrix
-#
 ##########################################################################
 
 edgelist.ergm <- function(x, ...) {
@@ -58,7 +26,7 @@ edgelist.ergm.default <- function(x, ...) {
 
 
 edgelist.ergm.network <- function(x, ...) {
-  edgelist.ergm(as.matrix.network.edgelist(x), directed=is.directed(x), ...)
+  edgelist.ergm(as.edgelist(x), directed=is.directed(x), ...)
 }
 
 
