@@ -1,67 +1,47 @@
 #  File ergm/R/ergm.MCMCse.lognormal.R
-#  Part of the statnet package, http://statnetproject.org
+#  Part of the statnet package, http://statnet.org
 #
 #  This software is distributed under the GPL-3 license.  It is free,
 #  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnetproject.org/attribution
+#    http://statnet.org/attribution
 #
-#  Copyright 2011 the statnet development team
+#  Copyright 2012 the statnet development team
 ######################################################################
 #############################################################################
 # The <ergm.MCMCse.lognormal> function computes and returns the MCMC lognormal
 # standard errors 
-#
-# --PARAMETERS--
-#   theta           :  the vector of theta coefficients
-#   theta0          :  the vector of initial theta coefficients
-#   statsmatrix     :  the matrix of network statistics
-#   statsmatrix.miss:  the matrix of network statistics on the network of
-#                      missing edges
-#   H               :  the Hessian matrix
-#   H.miss          :  the Hessian matrix on the network of missing edges
-#   model           :  the model, as returned by <ergm.getmodel>
-#   lag.max         :  the maximum lag at which to calculate the acf for the
-#                      the network corresponding to 'statsmatrix'; default=10
-#   lag.max.miss    :  the maximum lag at which to calculate the acf for the
-#                      the network corresponding to 'statsmatrix.miss';
-#                      default=lag.max
-#
-# --RETURNED--
-#   mc.se: the vector of MCMC lognormal standard error estimates for each theta
-#          parameter
-#
 ################################################################################
 
-ergm.MCMCse.lognormal<-function(theta, theta0, statsmatrix, statsmatrix.miss,
-                      H, H.miss, model, 
-                      lag.max=10, lag.max.miss=lag.max) {
+ergm.MCMCse.lognormal<-function(theta, init, statsmatrix, statsmatrix.obs,
+                      H, H.obs, model, 
+                      lag.max=10, lag.max.obs=lag.max) {
   # Not sure why this is necessary, but:
-  names(theta) <- names(theta0)
+  names(theta) <- names(init)
 
   # Transform theta to eta
   etamap <- model$etamap
-  eta0 <- ergm.eta(theta0, etamap)
+  eta0 <- ergm.eta(init, etamap)
   eta <-  ergm.eta(theta, etamap)
   offsettheta <- model$etamap$offsettheta
   offsetmap <- model$etamap$offsetmap
 
-  # Center statmatrix (and statsmatrix.miss, if applicable)
+  # Center statmatrix (and statsmatrix.obs, if applicable)
   av <- apply(statsmatrix, 2, mean)
 # av <- apply(statsmatrix,2,median)
   xsim <- sweep(statsmatrix, 2, av, "-")
   xobs <- -av
-  if(!is.null(statsmatrix.miss)){
-   av.miss <- apply(statsmatrix.miss, 2, mean)
-#  av.miss <- apply(statsmatrix.miss, 2, median)
-   xsim.miss <- sweep(statsmatrix.miss, 2, av.miss,"-")
-   xsim.miss <- xsim.miss[,!offsetmap, drop=FALSE]
-   xobs <- av.miss-av
+  if(!is.null(statsmatrix.obs)){
+   av.obs <- apply(statsmatrix.obs, 2, mean)
+#  av.obs <- apply(statsmatrix.obs, 2, median)
+   xsim.obs <- sweep(statsmatrix.obs, 2, av.obs,"-")
+   xsim.obs <- xsim.obs[,!offsetmap, drop=FALSE]
+   xobs <- av.obs-av
   }
   xobs <- xobs[!offsetmap]
   xsim <- xsim[,!offsetmap, drop=FALSE]
 
-  # Take any theta offsets (values fixed at theta0) into consideration
-  theta.offset <- etamap$theta0
+  # Take any theta offsets (values fixed at init) into consideration
+  theta.offset <- etamap$init
   theta.offset[!offsettheta] <- theta[!offsettheta]
 
   #  Calculate the auto-covariance of the MCMC suff. stats.
@@ -93,26 +73,26 @@ ergm.MCMCse.lognormal<-function(theta, theta0, statsmatrix, statsmatrix.miss,
 
   #  Calculate the auto-covariance of the Conditional MCMC suff. stats.
   #  and hence the Conditional MCMC s.e.
-  E.miss <- 0
-  lag.max.miss <- lag.max
-  if(!is.null(statsmatrix.miss)){
-    z <- xsim.miss
-    R <- acf(z, lag.max = lag.max.miss, type = "covariance", plot = FALSE)$acf
+  E.obs <- 0
+  lag.max.obs <- lag.max
+  if(!is.null(statsmatrix.obs)){
+    z <- xsim.obs
+    R <- acf(z, lag.max = lag.max.obs, type = "covariance", plot = FALSE)$acf
     if(dim(R)[2] > 1){
       part <- apply(R[-1,  ,  ,drop=FALSE], c(2, 3), sum)
     }else{
       part <- matrix(sum(R[-1,  ,  , drop=FALSE]))
     }
-    cov.zbar.miss <- (R[1,  ,  ] + part + t(part))/nrow(xsim.miss)
-    cov.zbar.miss <- suppressWarnings(chol(cov.zbar.miss, pivot=TRUE))
-    cov.zbar.offset[!offsetmap,!offsetmap] <- cov.zbar.miss
+    cov.zbar.obs <- (R[1,  ,  ] + part + t(part))/nrow(xsim.obs)
+    cov.zbar.obs <- suppressWarnings(chol(cov.zbar.obs, pivot=TRUE))
+    cov.zbar.offset[!offsetmap,!offsetmap] <- cov.zbar.obs
     cov.zbar.offset <- t(ergm.etagradmult(theta.offset, t(cov.zbar.offset), etamap))
-    cov.zbar.miss <- crossprod(cov.zbar.offset, cov.zbar.offset)
-    novar <- novar | (diag(H.miss)==0)
-    H.miss <- H.miss[!novar,,drop=FALSE] 
-    H.miss <- H.miss[,!novar,drop=FALSE] 
-    cov.zbar.miss <- cov.zbar.miss[!novar,,drop=FALSE] 
-    cov.zbar.miss <- cov.zbar.miss[,!novar,drop=FALSE] 
+    cov.zbar.obs <- crossprod(cov.zbar.offset, cov.zbar.offset)
+    novar <- novar | (diag(H.obs)==0)
+    H.obs <- H.obs[!novar,,drop=FALSE] 
+    H.obs <- H.obs[,!novar,drop=FALSE] 
+    cov.zbar.obs <- cov.zbar.obs[!novar,,drop=FALSE] 
+    cov.zbar.obs <- cov.zbar.obs[,!novar,drop=FALSE] 
   }
   if(nrow(H)==1){
     H <- as.matrix(H[!novar,]) 
@@ -138,12 +118,12 @@ ergm.MCMCse.lognormal<-function(theta, theta0, statsmatrix, statsmatrix.miss,
   if(!(inherits(mc.se0,"try-error"))){
     mc.se0 <- try(diag(solve(H, t(mc.se0))), silent=TRUE)
     if(!(inherits(mc.se0,"try-error"))){
-      if(!is.null(statsmatrix.miss)){
-        mc.se.miss0 <- try(solve(H.miss, cov.zbar.miss), silent=TRUE)
-        if(!(inherits(mc.se.miss0,"try-error"))){
-          mc.se.miss0 <- try(diag(solve(H.miss, t(mc.se.miss0))), silent=TRUE)
-          if(!inherits(mc.se.miss0,"try-error")){
-            mc.se[!novar] <- sqrt(mc.se0 + mc.se.miss0)
+      if(!is.null(statsmatrix.obs)){
+        mc.se.obs0 <- try(solve(H.obs, cov.zbar.obs), silent=TRUE)
+        if(!(inherits(mc.se.obs0,"try-error"))){
+          mc.se.obs0 <- try(diag(solve(H.obs, t(mc.se.obs0))), silent=TRUE)
+          if(!inherits(mc.se.obs0,"try-error")){
+            mc.se[!novar] <- sqrt(mc.se0 + mc.se.obs0)
           }else{
             mc.se[!novar] <- sqrt(mc.se0)
           }
