@@ -1,46 +1,16 @@
 #  File ergm/R/ergm.degeneracy.R
-#  Part of the statnet package, http://statnetproject.org
+#  Part of the statnet package, http://statnet.org
 #
 #  This software is distributed under the GPL-3 license.  It is free,
 #  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnetproject.org/attribution
+#    http://statnet.org/attribution
 #
-#  Copyright 2011 the statnet development team
+#  Copyright 2012 the statnet development team
 ######################################################################
-#==================================================================================
-# This file contains the following 2 functions for assessing degeneracy
-#            <ergm.degeneracy>
-#            <ergm.compute.degeneracy>
-#==================================================================================
-
-
-
-
-
 ####################################################################################
 # The <ergm.degeneracy> function checks a given ergm object for degeneracy by
 # computing and returning the instability value of the model and the value
 # of the log-likelihood function at the maximized theta values
-#
-# --PARAMETERS--
-#   object   :  an ergm object
-#   control  :  the list of controls as returned by <control.ergm>;
-#               default=control.ergm()
-#   fast     :  whether the degeneracy check should be "fast", i.e to sample
-#               changeobs(?) when there are > 100, rather than use all changeobs;
-#               default=TRUE
-#   test.only:  whether to silence printing of the model instability calculation
-#               (T or F); this parameter is ignored if the instability > 1;
-#               default=FALSE
-#   verbose  :  whether to print a notification when 'object' is deemed degenerate
-#               (T or F); default=FALSE
-#
-#
-# --RETURNED--
-#   the original ergm object with 2 additional components:
-#     degeneracy.value:  the instability of the model
-#     degeneracy.type :  the vector returned by <ergm.compute.degeneracy>;
-#
 #######################################################################################
 
 ergm.degeneracy <- function(object, 
@@ -56,7 +26,7 @@ ergm.degeneracy <- function(object,
    if(is.null(object$mplefit$glm)){
     current.warn <- options()$warn
     options(warn=-1)
-    fit <- try(ergm(object$formula, MPLEonly=TRUE, Mlestimate=FALSE),silent=TRUE)
+    fit <- try(ergm(object$formula, estimate="MPLE"),silent=TRUE)
     options(warn=current.warn)
     if(inherits(fit,"try-error")){
      object$degeneracy.value <- NA
@@ -70,7 +40,7 @@ ergm.degeneracy <- function(object,
     }
    }
    # So a MCMC fit
-   if(object$loglikelihood>control$trustregion-0.1){
+   if(object$loglikelihood>control$MCMLE.trustregion-0.1){
     object$degeneracy.value <- Inf
    }else{
     changeobs <- (-2*object$mplefit$glm$y+1)*model.matrix(object$mplefit$glm)
@@ -86,9 +56,9 @@ ergm.degeneracy <- function(object,
     }
     object$degeneracy.type <- try(
       apply(changeobs, 1, ergm.compute.degeneracy,
-      theta0=object$MCMCtheta, etamap=object$etamap, 
+      init=object$MCMCtheta, etamap=object$etamap, 
       statsmatrix=object$sample[,!object$etamap$offsettheta,drop=FALSE],
-      trustregion=control$trustregion),silent=TRUE)
+      trustregion=control$MCMLE.trustregion),silent=TRUE)
     if(inherits(object$degeneracy.type,"try-error")){
      object$degeneracy.value <- Inf
      object$degeneracy.type <- NULL
@@ -127,7 +97,7 @@ ergm.degeneracy <- function(object,
     object$degeneracy.type <- NULL
    }
   }
-  if(object$degeneracy.value>control$trustregion-0.1){
+  if(object$degeneracy.value>control$MCMLE.trustregion-0.1){
    object$degeneracy.value <- Inf
   }
   if(is.infinite(object$degeneracy.value)){
@@ -154,63 +124,30 @@ ergm.degeneracy <- function(object,
 #######################################################################################
 # The <ergm.compute.degeneracy> function is a helper function to <ergm.degenarcy> that
 # establishes the 'degeneracy.type'
-#
-# --PARAMETERS--
-#   xobs       : the changeobs
-#   theta0     : the initial model parameters
-#   etamap     : the theta-> eta mapping, as returned by <ergm.etamap>
-#   statsmatrix: the sample summary statistics
-#   nr.maxit   : the maximum number of iterations to be used by the native R
-#                routine <optim>; default=100
-#   nr.reltol  : the relative convergence tolerance; see ?optim for details;
-#                default=.01
-#   verbose    : whether the result as degenerate or not should be printed (T or F);
-#                default=FALSE
-#   trace      : an integer specifying how many levels of tracing should
-#                should be printed during optimazition via the <optim> routine;
-#                default=6*verbose
-#   hessian    : whether a numerically differentiated Hessian matrix should be
-#                returned by <optim>; default=FALSE
-#   guess      : initial values used by the optimization routine <optim> ;
-#   trustregion:  the maximum value of the log-likelihood ratio that is trusted;
-#                default=20   
-#
-#
-# --IGNORED PARAMETERS--
-#   epsilon: ??; default=1e-10 
-#   ...    : to accomodate additional parameters passed from within the program   
-# 
-# --RETURNED--
-#   a 2-element vector containing  
-#     loglikelihood: the value of the log-likelihood function corresponding to 'theta';
-#                    if degenerate, this is a vector of Inf
-#     theta        : the vector of theta values found through maximixing the log-
-#                    likelihood; if degenerate, this is 'guess'
-#
 ##########################################################################################
 
-ergm.compute.degeneracy<-function(xobs, theta0, etamap, statsmatrix,
+ergm.compute.degeneracy<-function(xobs, init, etamap, statsmatrix,
                         epsilon=1e-10, nr.maxit=100, nr.reltol=0.01,
                         verbose=FALSE, trace=6*verbose,
-                        hessian=FALSE, guess=theta0,
+                        hessian=FALSE, guess=init,
                         trustregion=20, ...) {
   samplesize <- dim(statsmatrix)[1]
   statsmatrix0 <- statsmatrix
   probs <- rep(1/nrow(statsmatrix0),nrow(statsmatrix0))
-  statsmatrix0.miss <- NULL
-  probs.miss <- NULL
+  statsmatrix0.obs <- NULL
+  probs.obs <- NULL
   av <- apply(sweep(statsmatrix0,1,probs,"*"), 2, sum)
   xsim <- sweep(statsmatrix0, 2, av,"-")
-  xsim.miss <- NULL
-  probs.miss <- NULL
+  xsim.obs <- NULL
+  probs.obs <- NULL
 # xobs0 <- summary(model$formula)
   xobs <- -xobs - av
 #
 # Set up the initial estimate
 #
-  if (verbose) cat("Converting theta0 to eta0\n")
-  eta0 <- ergm.eta(theta0, etamap) #unsure about this
-  etamap$theta0 <- theta0
+  if (verbose) cat("Converting init to eta0\n")
+  eta0 <- ergm.eta(init, etamap) #unsure about this
+  etamap$init <- init
 #
 # Log-Likelihood and gradient functions
 #
@@ -224,7 +161,7 @@ ergm.compute.degeneracy<-function(xobs, theta0, etamap, statsmatrix,
                                  maxit=nr.maxit),
                     xobs=xobs,
                     xsim=xsim, probs=probs,
-                    xsim.miss=xsim.miss, probs.miss=probs.miss,
+                    xsim.obs=xsim.obs, probs.obs=probs.obs,
                     varweight=varweight, trustregion=trustregion,
                     eta0=eta0, etamap=etamap),silent=TRUE)
   if(verbose){cat("the change in the log-likelihood is", Lout$value,"\n")}
@@ -237,10 +174,10 @@ ergm.compute.degeneracy<-function(xobs, theta0, etamap, statsmatrix,
     return(c(Inf, guess))
   }
   theta <- Lout$par
-  names(theta) <- names(theta0)
+  names(theta) <- names(init)
 # c0  <- llik.fun(theta=Lout$par, xobs=xobs,
 #                 xsim=xsim, probs=probs,
-#                 xsim.miss=xsim.miss, probs.miss=probs.miss,
+#                 xsim.obs=xsim.obs, probs.obs=probs.obs,
 #                 varweight=0.5, eta0=eta0, etamap=etamap)
   loglikelihood <- Lout$value
   names(loglikelihood) <- "delta.log.lik"
