@@ -1,25 +1,15 @@
 #  File ergm/R/ergm.eta.R
-#  Part of the statnet package, http://statnetproject.org
+#  Part of the statnet package, http://statnet.org
 #
 #  This software is distributed under the GPL-3 license.  It is free,
 #  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnetproject.org/attribution
+#    http://statnet.org/attribution
 #
-#  Copyright 2011 the statnet development team
+#  Copyright 2012 the statnet development team
 ######################################################################
 ##############################################################################
 # The <ergm.eta> function calculates and returns eta, mapped from
 # theta using the etamap object created by <ergm.etamap>.
-#
-# --PARAMETERS--
-#   theta :  the curved model parameters  
-#   etamap:  the list of values that constitutes the theta-> eta mapping
-#            and is returned by <ergm.etamap>
-#
-# --RETURNED--
-#   eta:  the canonical eta parameters as mapped from theta; infinite parameters
-#         are replaced by -10000
-#
 ###############################################################################
 
 ergm.eta <- function(theta, etamap) {
@@ -32,6 +22,84 @@ ergm.eta <- function(theta, etamap) {
       eta[cm$to] <- cm$map(theta[cm$from],length(cm$to),cm$cov)
     }
   }
-  eta[is.infinite(eta)] <- -10000
+  eta[is.infinite(eta)] <- sign(eta[is.infinite(eta)])*1000
   eta
 }
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
