@@ -1,41 +1,18 @@
 #  File ergm/R/network.update.R
-#  Part of the statnet package, http://statnetproject.org
+#  Part of the statnet package, http://statnet.org
 #
 #  This software is distributed under the GPL-3 license.  It is free,
 #  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnetproject.org/attribution
+#    http://statnet.org/attribution
 #
-#  Copyright 2011 the statnet development team
+#  Copyright 2012 the statnet development team
 ######################################################################
-#============================================================================
-# This file contains the following 3 functions used to update networks:
-#          <network.update>
-#          <as.edgelist.compressed>
-#          <as.network.uncompressed>
-#===========================================================================
-
-
-
 ###############################################################################
 # The <network.update> function returns the given network with with only the
 # ties specified by a given matrix
-#
-# --PARAMETERS--
-#   nw         : a network object
-#   newmatrix  : the matrix specifying the new set of ties with which to
-#                update 'nw' 
-#   matrix.type: the type of matrix that 'newmatrix' is, as "adjacency" or
-#                "edgelist"; default=which.matrix.type(newmatrix)
-#   output     : a string indicating whether the output should be an
-#                edgelist (using "edgelist.compressed") or should be a 
-#                network (using any other string); default="network"
-#
-# --RETURNED--
-#   unw:  the updated network, having only those ties specified by 'newmatrix'
-#
 ###############################################################################
 
-network.update<-function(nw,newmatrix,matrix.type=NULL,output="network")
+network.update<-function(nw, newmatrix, matrix.type=NULL, output="network")
 {
 #  print(paste("old:",network.edgecount(nw)," new:", nrow(newmatrix),collapse=" "))
   unw <- network.copy(as.network.uncompressed(nw))
@@ -44,8 +21,7 @@ network.update<-function(nw,newmatrix,matrix.type=NULL,output="network")
     matrix.type <- which.matrix.type(newmatrix)
     if(nrow(newmatrix)==0){matrix.type <- "edgelist"}
   }
-  if(matrix.type=="adjacency" 
-     && max(abs(newmatrix))==1 && max(abs(newmatrix-as.integer(newmatrix)))==0){
+  if(matrix.type=="adjacency" && all(newmatrix%in%c(0,1))){
     unw[,] <- newmatrix
   }else if(matrix.type=="edgelist"){
 #  cnw <- as.matrix.network(nw,matrix.type="edgelist")
@@ -73,23 +49,6 @@ network.update<-function(nw,newmatrix,matrix.type=NULL,output="network")
 ###############################################################################
 # The <as.edgelist.compressed> function converts a network 'x' into the edgelist
 # 'out' described below; this is a copy of <as.edgelist.san>
-#
-# --PARAMETERS--
-#   x              : a network object, or a list of such
-#   attrname       : optionally, the name of an edge attribute to use for edge
-#                    values; default=NULL
-#   force.bipartite: whether ?? if 'x' is not already bipartite(T or F); default=FALSE; if TRUE,
-#                    this appears to merely create the 'input must be a network'
-#                    warning, before finishing up as if this were FALSE
-#
-# --RETURNED--
-#   out: x, as an edgelist with attributes for
-#       n                : the network size
-#       directed         : whether the network is directed (T or F)
-#       vnames           : the vertex names
-#       vertex.attributes: a list of the vertex attributes
-#       bipartite        : whether the network is bipartite (T or F)
-#
 ###############################################################################
 
 as.edgelist.compressed<-function(x, attrname=NULL, force.bipartite=FALSE){
@@ -134,21 +93,6 @@ as.edgelist.compressed<-function(x, attrname=NULL, force.bipartite=FALSE){
 ###############################################################################
 # The <as.network.uncompressed> function is basically the inverse of the above
 # <as.edgelist.compressed> function
-#
-# --PARAMETERS--
-#   x         : a compressed network or a network
-#   edge.check: whether computationally expensive checks of the legality
-#               of submitted edges should be performed (T or F); default=FALSE
-#
-# --IGNORED PARAMTERS--
-#   na.rm:  whether NA valuse should be removed for ??; default=FALSE
-#   ...  :  additional parameters for flexibility
-#
-# --RETURNED--
-#   x: the original network if it is already uncompressed or if 'x' is neither
-#      a compressed or uncompressed network
-#   g: the uncompressed version of x
-#
 ###############################################################################
 
 as.network.uncompressed<-function(x, 
